16.43. cdist-type__docker_swarm(7) — cdist 4.11.0 documentation

# 16.43. cdist-type__docker_swarm(7)

## 16.43.1. NAME

cdist-type__docker_swarm - Manage Swarm

## 16.43.2. DESCRIPTION

This type can initialize Docker swarm mode. For more information about swarm mode, see Swarm mode overview.

## 16.43.3. OPTIONAL PARAMETERS

state

  'present' or 'absent', defaults to 'present' where:

  present
    Swarm is initialized
  absent
    Swarm is left

## 16.43.4. EXAMPLES

    # Initializes a swarm
    __docker_swarm

    # Leaves a swarm
    __docker_swarm --state absent

## 16.43.5. AUTHORS

Ľubomír Kučera <lubomir.kucera.jr at gmail.com>

## 16.43.6. COPYING

Copyright (C) 2018 Ľubomír Kučera. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.